# Change Log

## 3.0.0
## Added
- download as
- documents conversion
- connection to a demo document server
- settings validation
- mail merge from storage
- compare file from storage
- insert image from storage
- advanced server settings for specifying internal addresses

## Changed
- parameter document.title for editor from file object title
- document server v6.0 and earlier is no longer supported

## 2.1.1
## Fixed
- issue with packaging

## 2.1.0
## Added
- support docxf and oform formats
- create blank docxf from creation menu
- "save as" in editor

## 2.0.0
## Added
 - JWT support
## Fixed
 - Issue when files inside unpublished folders couldn't be edited

## 1.0.0
## Added
 - Edit option for DOCX, XLSX, PPTX.
 - View template for documents
 - Configuration page
 - Translations for BR, CZ, DE, EN, ES, FR, IT, JP, NL, RU, ZH